@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/GeometryVisitor.h>
 #include <SFCGAL/LineString.h>
@@ -10,12 +10,12 @@ namespace SFCGAL {
 ///
 ///
 ///
-LineString::LineString() : Geometry(), _points() {}
+LineString::LineString() = default;
 
 ///
 ///
 ///
-LineString::LineString(const std::vector<Point> &points) : Geometry(), _points()
+LineString::LineString(const std::vector<Point> &points)
 {
   for (const auto &point : points) {
     _points.push_back(point.clone());
@@ -26,7 +26,7 @@ LineString::LineString(const std::vector<Point> &points) : Geometry(), _points()
 ///
 ///
 LineString::LineString(const Point &startPoint, const Point &endPoint)
-    : Geometry(), _points()
+
 {
   _points.push_back(startPoint.clone());
   _points.push_back(endPoint.clone());
@@ -154,9 +154,8 @@ LineString::numSegments() const -> size_t
 {
   if (_points.empty()) {
     return 0;
-  } else {
-    return _points.size() - 1;
   }
+  return _points.size() - 1;
 }
 
 ///
