@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/GeometryVisitor.h>
 #include <SFCGAL/MultiLineString.h>
@@ -10,7 +10,7 @@ namespace SFCGAL {
 ///
 ///
 ///
-MultiLineString::MultiLineString() : GeometryCollection() {}
+MultiLineString::MultiLineString() = default;
 
 ///
 ///
