@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/GeometryVisitor.h>
 #include <SFCGAL/Surface.h>
@@ -24,7 +24,7 @@ Surface::dimension() const -> int
 ///
 ///
 ///
-Surface::Surface() : Geometry() {}
+Surface::Surface() = default;
 
 ///
 ///
