@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/GeometryVisitor.h>
 #include <SFCGAL/Triangle.h>
@@ -12,7 +12,7 @@ namespace SFCGAL {
 ///
 ///
 ///
-Triangle::Triangle() : Surface()
+Triangle::Triangle()
 {
   _vertices[0] = Point();
   _vertices[1] = Point();
@@ -42,7 +42,7 @@ Triangle::Triangle(const Kernel::Triangle_3 &triangle)
 ///
 ///
 ///
-Triangle::Triangle(const Point &p, const Point &q, const Point &r) : Surface()
+Triangle::Triangle(const Point &p, const Point &q, const Point &r)
 {
   _vertices[0] = p;
   _vertices[1] = q;
