@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <CGAL/intersections.h>
 
@@ -19,8 +19,7 @@
 
 using namespace SFCGAL::detail;
 
-namespace SFCGAL {
-namespace algorithm {
+namespace SFCGAL::algorithm {
 
 void
 _intersection_solid_segment(const PrimitiveHandle<3> &pa,
@@ -35,17 +34,18 @@ _intersection_solid_segment(const PrimitiveHandle<3> &pa,
   const auto *segment = pb.as<CGAL::Segment_3<Kernel>>();
 
   auto *ext_poly_nc = const_cast<MarkedPolyhedron *>(ext_poly);
-  CGAL::Side_of_triangle_mesh<MarkedPolyhedron, Kernel> is_in_ext(*ext_poly_nc);
+  CGAL::Side_of_triangle_mesh<MarkedPolyhedron, Kernel> const is_in_ext(
+      *ext_poly_nc);
 
-  GeometrySet<3> triangles;
-  GeometrySet<3> spoint(segment->source());
-  GeometrySet<3> tpoint(segment->target());
+  GeometrySet<3>       triangles;
+  GeometrySet<3> const spoint(segment->source());
+  GeometrySet<3> const tpoint(segment->target());
   triangulate::triangulate(*ext_poly, triangles);
 
-  bool source_inside =
+  bool const source_inside =
       (is_in_ext(segment->source()) != CGAL::ON_UNBOUNDED_SIDE) ||
       intersects(triangles, spoint);
-  bool target_inside =
+  bool const target_inside =
       (is_in_ext(segment->target()) != CGAL::ON_UNBOUNDED_SIDE) ||
       intersects(triangles, tpoint);
 
@@ -53,7 +53,8 @@ _intersection_solid_segment(const PrimitiveHandle<3> &pa,
     // the entire segment intersects the volume, return the segment
     output.addPrimitive(pb);
   } else {
-    GeometrySet<3> triangles, g;
+    GeometrySet<3> triangles;
+    GeometrySet<3> g;
     triangulate::triangulate(*ext_poly, triangles);
     g.addPrimitive(pb);
     GeometrySet<3> inter;
@@ -65,8 +66,8 @@ _intersection_solid_segment(const PrimitiveHandle<3> &pa,
       // the intersection is a point, build a segment from that point to the
       // other end
       if (!source_inside && target_inside) {
-        CGAL::Segment_3<Kernel> interSeg(inter.points().begin()->primitive(),
-                                         segment->target());
+        CGAL::Segment_3<Kernel> const interSeg(
+            inter.points().begin()->primitive(), segment->target());
 
         if (interSeg.source() == interSeg.target()) {
           output.addPrimitive(segment->target());
@@ -74,8 +75,8 @@ _intersection_solid_segment(const PrimitiveHandle<3> &pa,
           output.addPrimitive(interSeg);
         }
       } else if (source_inside && !target_inside) {
-        CGAL::Segment_3<Kernel> interSeg(segment->source(),
-                                         inter.points().begin()->primitive());
+        CGAL::Segment_3<Kernel> const interSeg(
+            segment->source(), inter.points().begin()->primitive());
 
         if (interSeg.source() == interSeg.target()) {
           output.addPrimitive(segment->source());
@@ -114,18 +115,19 @@ _intersection_solid_triangle(const MarkedPolyhedron         &pa,
   MarkedPolyhedron polyb;
   polyb.make_triangle(tri.vertex(0), tri.vertex(1), tri.vertex(2));
 
-  MarkedPolyhedron                                      polya = pa;
-  CGAL::Side_of_triangle_mesh<MarkedPolyhedron, Kernel> side_of_tm(polya);
+  MarkedPolyhedron                                            polya = pa;
+  CGAL::Side_of_triangle_mesh<MarkedPolyhedron, Kernel> const side_of_tm(polya);
 
   std::list<Polyline_3> polylines;
   CGAL::Polygon_mesh_processing::surface_intersection(
       polya, polyb, std::back_inserter(polylines));
-  if (polylines.size() == 0) {
+  if (polylines.empty()) {
     // no surface intersection
     // if one of the point of the triangle is inside the polyhedron,
     // the triangle is inside
-    if (side_of_tm(tri.vertex(0)) != CGAL::ON_UNBOUNDED_SIDE)
+    if (side_of_tm(tri.vertex(0)) != CGAL::ON_UNBOUNDED_SIDE) {
       output.addPrimitive(tri);
+    }
     return;
   }
 
@@ -140,14 +142,15 @@ _intersection_solid_triangle(const MarkedPolyhedron         &pa,
   for (const MarkedPolyhedron &mp : ccs) {
     // check if all vertices are on polya
     bool all_on = true;
-    for (auto v : vertices(mp))
+    for (auto v : vertices(mp)) {
       if (side_of_tm(v->point()) != CGAL::ON_BOUNDARY) {
         all_on = false;
         break;
       }
-    if (all_on)
+    }
+    if (all_on) {
       output.addPrimitive(mp);
-    else {
+    } else {
       hasSurface = true;
       output.addPrimitive(mp, FLAG_IS_PLANAR);
     }
@@ -157,14 +160,13 @@ _intersection_solid_triangle(const MarkedPolyhedron         &pa,
     return;
   }
 
-  for (std::list<Polyline_3>::const_iterator lit = polylines.begin();
-       lit != polylines.end(); ++lit) {
-    if (lit->size() == 1) {
+  for (auto &polyline : polylines) {
+    if (polyline.size() == 1) {
       // it's a point
-      output.addPrimitive((*lit)[0]);
+      output.addPrimitive(polyline[0]);
     } else {
-      for (size_t k = 1; k < lit->size(); ++k) {
-        CGAL::Segment_3<Kernel> seg((*lit)[k - 1], (*lit)[k]);
+      for (size_t k = 1; k < polyline.size(); ++k) {
+        CGAL::Segment_3<Kernel> const seg(polyline[k - 1], polyline[k]);
         output.addPrimitive(seg);
       }
     }
@@ -181,7 +183,8 @@ _intersection_solid_solid(const MarkedPolyhedron &pa,
   // (but no surfaces ...)
   {
     // call CGAL::intersection on triangles
-    GeometrySet<3> gsa, gsb;
+    GeometrySet<3> gsa;
+    GeometrySet<3> gsb;
     // convert polyhedra to geometry sets
     // (no actual triangulation is done if the polyhedra are pure_triangle()
     triangulate::triangulate(pa, gsa);
@@ -192,11 +195,14 @@ _intersection_solid_solid(const MarkedPolyhedron &pa,
 
   // 2. find intersections in volumes
   {
-    MarkedPolyhedron polya = pa, polyb = pb;
+    MarkedPolyhedron polya = pa;
+    MarkedPolyhedron polyb = pb;
     if (CGAL::Polygon_mesh_processing::corefine_and_compute_intersection(
-            polya, polyb, polya))
-      if (std::next(vertices(polya).first) != vertices(polya).second)
+            polya, polyb, polya)) {
+      if (std::next(vertices(polya).first) != vertices(polya).second) {
         output.addPrimitive(polya);
+      }
+    }
   }
 }
 
@@ -204,7 +210,7 @@ _intersection_solid_solid(const MarkedPolyhedron &pa,
 // must be called with pa's dimension larger than pb's
 void
 intersection(const PrimitiveHandle<3> &pa, const PrimitiveHandle<3> &pb,
-             GeometrySet<3> &output, dim_t<3>)
+             GeometrySet<3> &output, dim_t<3> /*unused*/)
 {
   // everything vs a point
   if (pb.handle.which() == PrimitivePoint) {
@@ -214,20 +220,20 @@ intersection(const PrimitiveHandle<3> &pa, const PrimitiveHandle<3> &pb,
     }
   } else if (pa.handle.which() == PrimitiveSegment &&
              pb.handle.which() == PrimitiveSegment) {
-    const auto  *seg1     = pa.as<CGAL::Segment_3<Kernel>>();
-    const auto  *seg2     = pb.as<CGAL::Segment_3<Kernel>>();
-    CGAL::Object interObj = CGAL::intersection(*seg1, *seg2);
+    const auto        *seg1     = pa.as<CGAL::Segment_3<Kernel>>();
+    const auto        *seg2     = pb.as<CGAL::Segment_3<Kernel>>();
+    CGAL::Object const interObj = CGAL::intersection(*seg1, *seg2);
     output.addPrimitive(interObj);
   } else if (pa.handle.which() == PrimitiveSurface) {
     const auto *tri1 = pa.as<CGAL::Triangle_3<Kernel>>();
 
     if (pb.handle.which() == PrimitiveSegment) {
-      const auto  *seg2     = pb.as<CGAL::Segment_3<Kernel>>();
-      CGAL::Object interObj = CGAL::intersection(*tri1, *seg2);
+      const auto        *seg2     = pb.as<CGAL::Segment_3<Kernel>>();
+      CGAL::Object const interObj = CGAL::intersection(*tri1, *seg2);
       output.addPrimitive(interObj);
     } else if (pb.handle.which() == PrimitiveSurface) {
-      const auto  *tri2     = pb.as<CGAL::Triangle_3<Kernel>>();
-      CGAL::Object interObj = CGAL::intersection(*tri1, *tri2);
+      const auto        *tri2     = pb.as<CGAL::Triangle_3<Kernel>>();
+      CGAL::Object const interObj = CGAL::intersection(*tri1, *tri2);
       output.addPrimitive(interObj, /* pointsAsRing */ true);
     }
   } else if (pa.handle.which() == PrimitiveVolume) {
@@ -246,5 +252,4 @@ intersection(const PrimitiveHandle<3> &pa, const PrimitiveHandle<3> &pb,
   }
 }
 
-} // namespace algorithm
-} // namespace SFCGAL
+} // namespace SFCGAL::algorithm
