@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/algorithm/collect.h>
 
@@ -10,8 +10,7 @@
 #include <SFCGAL/MultiPolygon.h>
 #include <SFCGAL/MultiSolid.h>
 
-namespace SFCGAL {
-namespace algorithm {
+namespace SFCGAL::algorithm {
 auto
 collect(const Geometry &ga, const Geometry &gb) -> std::unique_ptr<Geometry>
 {
@@ -21,17 +20,20 @@ collect(const Geometry &ga, const Geometry &gb) -> std::unique_ptr<Geometry>
       mp->addGeometry(ga);
       mp->addGeometry(gb);
       return std::unique_ptr<Geometry>(mp);
-    } else if (ga.geometryTypeId() == TYPE_LINESTRING) {
+    }
+    if (ga.geometryTypeId() == TYPE_LINESTRING) {
       auto *mls = new MultiLineString();
       mls->addGeometry(ga);
       mls->addGeometry(gb);
       return std::unique_ptr<Geometry>(mls);
-    } else if (ga.geometryTypeId() == TYPE_POLYGON) {
+    }
+    if (ga.geometryTypeId() == TYPE_POLYGON) {
       auto *mp = new MultiPolygon();
       mp->addGeometry(ga);
       mp->addGeometry(gb);
       return std::unique_ptr<Geometry>(mp);
-    } else if (ga.geometryTypeId() == TYPE_SOLID) {
+    }
+    if (ga.geometryTypeId() == TYPE_SOLID) {
       auto *mp = new MultiSolid();
       mp->addGeometry(ga);
       mp->addGeometry(gb);
@@ -45,5 +47,4 @@ collect(const Geometry &ga, const Geometry &gb) -> std::unique_ptr<Geometry>
   coll->addGeometry(gb);
   return std::unique_ptr<Geometry>(coll);
 }
-} // namespace algorithm
-} // namespace SFCGAL
+} // namespace SFCGAL::algorithm
