@@ -1,18 +1,16 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/Triangle.h>
 // GOTCHA do not include the header, this is a trick to avoid ambiguous def in
 // CGAL
 
-namespace SFCGAL {
-namespace algorithm {
+namespace SFCGAL::algorithm {
 auto
 intersection(const CGAL::Triangle_3<Kernel> &a,
              const CGAL::Triangle_3<Kernel> &b) -> CGAL::Object
 {
   return CGAL::intersection(a, b);
 }
-} // namespace algorithm
-} // namespace SFCGAL
+} // namespace SFCGAL::algorithm
