@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/algorithm/extrude.h>
 
@@ -28,8 +28,7 @@
 
 #include <utility>
 
-namespace SFCGAL {
-namespace algorithm {
+namespace SFCGAL::algorithm {
 
 //-- private interface
 
@@ -38,7 +37,8 @@ extrude(const Point &g, const Kernel::Vector_3 &v) -> LineString *;
 auto
 extrude(const LineString &g, const Kernel::Vector_3 &v) -> PolyhedralSurface *;
 auto
-extrude(const Polygon &g, const Kernel::Vector_3 &v) -> Solid *;
+extrude(const Polygon &g, const Kernel::Vector_3 &v, bool addTop = true)
+    -> Solid *;
 auto
 extrude(const Triangle &g, const Kernel::Vector_3 &v) -> Solid *;
 
@@ -80,8 +80,8 @@ extrude(const Point &g, const Kernel::Vector_3 &v) -> LineString *
     return new LineString();
   }
 
-  Kernel::Point_3 a = g.toPoint_3();
-  Kernel::Point_3 b = a + v;
+  Kernel::Point_3 const a = g.toPoint_3();
+  Kernel::Point_3 const b = a + v;
 
   return new LineString(Point(a), Point(b));
 }
@@ -102,8 +102,8 @@ extrude(const LineString &g, const Kernel::Vector_3 &v) -> PolyhedralSurface *
   for (size_t i = 0; i < g.numPoints() - 1; i++) {
     std::unique_ptr<LineString> ring(new LineString);
 
-    Kernel::Point_3 a = g.pointN(i).toPoint_3();
-    Kernel::Point_3 b = g.pointN(i + 1).toPoint_3();
+    Kernel::Point_3 const a = g.pointN(i).toPoint_3();
+    Kernel::Point_3 const b = g.pointN(i + 1).toPoint_3();
     ring->addPoint(new Point(a));
     ring->addPoint(new Point(b));
     ring->addPoint(new Point(b + v));
@@ -120,13 +120,13 @@ extrude(const LineString &g, const Kernel::Vector_3 &v) -> PolyhedralSurface *
 ///
 ///
 auto
-extrude(const Polygon &g, const Kernel::Vector_3 &v) -> Solid *
+extrude(const Polygon &g, const Kernel::Vector_3 &v, bool addTop) -> Solid *
 {
   if (g.isEmpty()) {
     return new Solid();
   }
 
-  bool reverseOrientation = (v * normal3D<Kernel>(g)) > 0;
+  bool const reverseOrientation = (v * normal3D<Kernel>(g)) > 0;
 
   // resulting shell
   PolyhedralSurface polyhedralSurface;
@@ -142,11 +142,12 @@ extrude(const Polygon &g, const Kernel::Vector_3 &v) -> Solid *
   polyhedralSurface.addPolygon(bottom);
 
   // "top"
-  Polygon top(bottom);
-  top.reverse();
-  translate(top, v);
-  polyhedralSurface.addPolygon(top);
-
+  if (addTop) {
+    Polygon top(bottom);
+    top.reverse();
+    translate(top, v);
+    polyhedralSurface.addPolygon(top);
+  }
   // exterior ring and interior rings extruded
   for (size_t i = 0; i < bottom.numRings(); i++) {
     std::unique_ptr<PolyhedralSurface> boundaryExtruded(
@@ -363,18 +364,18 @@ extrude(const Geometry &g, const Kernel::Vector_3 &v)
 ///
 auto
 extrude(const Geometry &g, const Kernel::FT &dx, const Kernel::FT &dy,
-        const Kernel::FT &dz, NoValidityCheck) -> std::unique_ptr<Geometry>
+        const Kernel::FT &dz, NoValidityCheck /*unused*/)
+    -> std::unique_ptr<Geometry>
 {
   return extrude(g, Kernel::Vector_3(dx, dy, dz));
 }
 
 auto
-extrude(const Geometry &g, Kernel::FT dx, Kernel::FT dy, Kernel::FT dz)
-    -> std::unique_ptr<Geometry>
+extrude(const Geometry &g, const Kernel::FT &dx, const Kernel::FT &dy,
+        const Kernel::FT &dz) -> std::unique_ptr<Geometry>
 {
   SFCGAL_ASSERT_GEOMETRY_VALIDITY(g);
-  std::unique_ptr<Geometry> result(extrude(g, std::move(dx), std::move(dy),
-                                           std::move(dz), NoValidityCheck()));
+  std::unique_ptr<Geometry> result(extrude(g, dx, dy, dz, NoValidityCheck()));
   propagateValidityFlag(*result, true);
   return result;
 }
@@ -391,5 +392,16 @@ extrude(const Geometry &g, const double &dx, const double &dy, const double &dz)
   return extrude(g, Kernel::FT(dx), Kernel::FT(dy), Kernel::FT(dz));
 }
 
-} // namespace algorithm
-} // namespace SFCGAL
+SFCGAL_API auto
+extrude(const Polygon &g, const double &height) -> std::unique_ptr<Geometry>
+{
+
+  if (!std::isfinite(height)) {
+    BOOST_THROW_EXCEPTION(NonFiniteValueException(
+        "trying to extrude with non finite value in direction"));
+  }
+
+  return std::unique_ptr<Geometry>(
+      extrude(g, Kernel::Vector_3(0.0, 0.0, height), false));
+}
+} // namespace SFCGAL::algorithm
