@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #ifndef _SFCGAL_ALGORITHM_EXTRUDE_H_
 #define _SFCGAL_ALGORITHM_EXTRUDE_H_
@@ -37,7 +37,8 @@ struct NoValidityCheck;
  * @ingroup public_api
  */
 SFCGAL_API std::unique_ptr<Geometry>
-extrude(const Geometry &g, Kernel::FT dx, Kernel::FT dy, Kernel::FT dz);
+extrude(const Geometry &g, const Kernel::FT &dx, const Kernel::FT &dy,
+        const Kernel::FT &dz);
 
 /**
  * @brief Returns a Geometry equal to the specified Geometry,
@@ -62,8 +63,8 @@ extrude(const Geometry &g, Kernel::FT dx, Kernel::FT dy, Kernel::FT dz);
  * @warning No actual validity check is conducted.
  */
 SFCGAL_API std::unique_ptr<Geometry>
-extrude(const Geometry &g, Kernel::FT &dx, Kernel::FT &dy, Kernel::FT &dz,
-        NoValidityCheck &nvc);
+extrude(const Geometry &g, const Kernel::FT &dx, const Kernel::FT &dy,
+        const Kernel::FT &dz, NoValidityCheck &nvc);
 
 /**
  * @brief Returns a Geometry equal to the specified Geometry,
@@ -111,6 +112,8 @@ SFCGAL_API std::unique_ptr<Geometry>
 SFCGAL_API std::unique_ptr<Geometry>
            extrude(const Geometry &g, const Kernel::Vector_3 &v);
 
+SFCGAL_API std::unique_ptr<Geometry>
+           extrude(const Polygon &g, const double &height);
 } // namespace algorithm
 } // namespace SFCGAL
 
