@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #ifndef _SFCGAL_ALGORITHM_ISVALID_H_
 #define _SFCGAL_ALGORITHM_ISVALID_H_
@@ -47,8 +47,7 @@ propagateValidityFlag(Geometry &g, bool valid);
  * Tag used for variants of algorithm that do not do validity check
  * @ingroup public_api
  */
-struct NoValidityCheck {
-};
+struct NoValidityCheck {};
 
 } // namespace algorithm
 } // namespace SFCGAL
