@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/algorithm/offset.h>
 
@@ -40,8 +40,7 @@ using Offset_polygon_set_2        = CGAL::General_polygon_set_2<Gps_traits_2>;
 #define SFCGAL_OFFSET_ASSERT_FINITE_RADIUS(r)                                  \
   if (!std::isfinite(r))                                                       \
     BOOST_THROW_EXCEPTION(NonFiniteValueException("radius is non finite"));
-namespace SFCGAL {
-namespace algorithm {
+namespace SFCGAL::algorithm {
 
 //-- private interface
 
@@ -95,7 +94,9 @@ approximate(const Offset_polygon_2 &polygon, const int &n = 0) -> Polygon_2
   }
 
   // remove duplicated last point
-  pair_list.pop_back();
+  if (!pair_list.empty()) {
+    pair_list.pop_back();
+  }
 
   /*
    * convertr to polygon
@@ -105,10 +106,8 @@ approximate(const Offset_polygon_2 &polygon, const int &n = 0) -> Polygon_2
   bool            isFirst = true;
   Kernel::Point_2 last;
 
-  for (std::list<std::pair<double, double>>::const_iterator it =
-           pair_list.begin();
-       it != pair_list.end(); ++it) {
-    Kernel::Point_2 point(it->first, it->second);
+  for (auto &it : pair_list) {
+    Kernel::Point_2 const point(it.first, it.second);
 
     if (isFirst) {
       isFirst = false;
@@ -151,9 +150,8 @@ polygonSetToMultiPolygon(const Offset_polygon_set_2 &polygonSet, const int &n)
 
   std::unique_ptr<MultiPolygon> result(new MultiPolygon);
 
-  for (std::list<Offset_polygon_with_holes_2>::const_iterator it = res.begin();
-       it != res.end(); ++it) {
-    result->addGeometry(new Polygon(approximate(*it, n)));
+  for (auto &re : res) {
+    result->addGeometry(new Polygon(approximate(re, n)));
   }
 
   return result;
@@ -168,8 +166,8 @@ circleToPolygon(const Kernel::Circle_2 &circle) -> Offset_polygon_2
   /*
    * convert the circle into Offset_x_monotone_curve_2 (exactly 2)
    */
-  Gps_traits_2   traits;
-  Offset_curve_2 curve(circle);
+  Gps_traits_2 const   traits;
+  Offset_curve_2 const curve(circle);
 
   std::list<CGAL::Object> parts;
   traits.make_x_monotone_2_object()(curve, std::back_inserter(parts));
@@ -178,10 +176,9 @@ circleToPolygon(const Kernel::Circle_2 &circle) -> Offset_polygon_2
   // Construct the polygon.
   Offset_polygon_2 result;
 
-  for (std::list<CGAL::Object>::const_iterator it = parts.begin();
-       it != parts.end(); ++it) {
+  for (auto &part : parts) {
     Offset_x_monotone_curve_2 arc;
-    CGAL::assign(arc, *it);
+    CGAL::assign(arc, part);
     result.push_back(arc);
   }
 
@@ -195,7 +192,7 @@ void
 offset(const Point &gA, const double &radius, Offset_polygon_set_2 &polygonSet)
 {
   SFCGAL_OFFSET_ASSERT_FINITE_RADIUS(radius);
-  Kernel::Circle_2 circle(gA.toPoint_2(), radius * radius);
+  Kernel::Circle_2 const circle(gA.toPoint_2(), radius * radius);
 
   if (polygonSet.is_empty()) {
     polygonSet.insert(circleToPolygon(circle));
@@ -217,7 +214,7 @@ offset(const LineString &lineString, const double &radius,
     Polygon_2 P;
     P.push_back(lineString.pointN(i).toPoint_2());
     P.push_back(lineString.pointN(i + 1).toPoint_2());
-    Offset_polygon_with_holes_2 offset =
+    Offset_polygon_with_holes_2 const offset =
         CGAL::approximated_offset_2(P, radius, SFCGAL_OFFSET_ACCURACY);
 
     if (polygonSet.is_empty()) {
@@ -244,7 +241,7 @@ offset(const Polygon &g, const double &radius, Offset_polygon_set_2 &polygonSet)
    * Invoke minkowski_sum_2 for exterior ring
    */
   {
-    Offset_polygon_with_holes_2 offset = CGAL::approximated_offset_2(
+    Offset_polygon_with_holes_2 const offset = CGAL::approximated_offset_2(
         g.exteriorRing().toPolygon_2(), radius, SFCGAL_OFFSET_ACCURACY);
 
     if (polygonSet.is_empty()) {
@@ -345,7 +342,7 @@ offset(const Geometry &g, const double &radius,
 ///
 ///
 auto
-offset(const Geometry &g, const double &r, NoValidityCheck)
+offset(const Geometry &g, const double &r, NoValidityCheck /*unused*/)
     -> std::unique_ptr<MultiPolygon>
 {
   SFCGAL_OFFSET_ASSERT_FINITE_RADIUS(r);
@@ -362,5 +359,4 @@ offset(const Geometry &g, const double &r) -> std::unique_ptr<MultiPolygon>
   return offset(g, r, NoValidityCheck());
 }
 
-} // namespace algorithm
-} // namespace SFCGAL
+} // namespace SFCGAL::algorithm
