@@ -1,13 +1,13 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #ifndef _SFCGAL_ALGORITHM_PLANE_H_
 #define _SFCGAL_ALGORITHM_PLANE_H_
 
 #include <boost/format.hpp>
 
-//#include <SFCGAL/detail/ublas.h>
+// #include <SFCGAL/detail/ublas.h>
 
 #include <SFCGAL/Exception.h>
 #include <SFCGAL/Polygon.h>
@@ -97,8 +97,7 @@ plane3D(const Polygon &polygon)
                                nrml);
 }
 
-struct Plane3DInexactUnsafe {
-};
+struct Plane3DInexactUnsafe {};
 
 /**
  * Returns the oriented 3D plane of a polygon (supposed to be planar) - inexact
