@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/GeometryCollection.h>
 #include <SFCGAL/Solid.h>
@@ -9,14 +9,14 @@
 #include <SFCGAL/algorithm/tesselate.h>
 #include <SFCGAL/triangulate/triangulatePolygon.h>
 
-namespace SFCGAL {
-namespace algorithm {
+namespace SFCGAL::algorithm {
 
 ///
 ///
 ///
 auto
-tesselate(const Geometry &g, NoValidityCheck) -> std::unique_ptr<Geometry>
+tesselate(const Geometry &g, NoValidityCheck /*unused*/)
+    -> std::unique_ptr<Geometry>
 {
   switch (g.geometryTypeId()) {
   case TYPE_POINT:
@@ -75,5 +75,4 @@ tesselate(const Geometry &g) -> std::unique_ptr<Geometry>
   return tesselate(g, NoValidityCheck());
 }
 
-} // namespace algorithm
-} // namespace SFCGAL
+} // namespace SFCGAL::algorithm
