@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/algorithm/translate.h>
 
@@ -20,8 +20,7 @@
 #include <SFCGAL/detail/transform/AffineTransform2.h>
 #include <SFCGAL/detail/transform/AffineTransform3.h>
 
-namespace SFCGAL {
-namespace algorithm {
+namespace SFCGAL::algorithm {
 
 ///
 ///
@@ -49,11 +48,23 @@ translate(Geometry &g, const Kernel::Vector_2 &v)
 ///
 ///
 void
-translate(Geometry &g, const Kernel::FT dx, const Kernel::FT dy,
-          const Kernel::FT dz)
+translate(Geometry &g, const Kernel::FT &dx, const Kernel::FT &dy,
+          const Kernel::FT &dz)
 {
   translate(g, Kernel::Vector_3(dx, dy, dz));
 }
 
-} // namespace algorithm
-} // namespace SFCGAL
+///
+///
+///
+void
+translate(Geometry &g, const double &dx, const double &dy, const double &dz)
+{
+  if (!std::isfinite(dx) || !std::isfinite(dy) || !std::isfinite(dz)) {
+    BOOST_THROW_EXCEPTION(NonFiniteValueException(
+        "trying to translate with non finite value in direction"));
+  }
+
+  return translate(g, Kernel::FT(dx), Kernel::FT(dy), Kernel::FT(dz));
+}
+} // namespace SFCGAL::algorithm
