@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/Geometry.h>
 #include <SFCGAL/GeometryCollection.h>
@@ -21,9 +21,12 @@
 
 #include <SFCGAL/detail/io/Serialization.h>
 #include <SFCGAL/io/ewkt.h>
+#include <SFCGAL/io/wkb.h>
 #include <SFCGAL/io/wkt.h>
 
+#if !_MSC_VER
 #include <SFCGAL/algorithm/alphaShapes.h>
+#endif
 #include <SFCGAL/algorithm/area.h>
 #include <SFCGAL/algorithm/convexHull.h>
 #include <SFCGAL/algorithm/covers.h>
@@ -37,10 +40,12 @@
 #include <SFCGAL/algorithm/lineSubstring.h>
 #include <SFCGAL/algorithm/minkowskiSum.h>
 #include <SFCGAL/algorithm/offset.h>
+#include <SFCGAL/algorithm/partition_2.h>
 #include <SFCGAL/algorithm/plane.h>
 #include <SFCGAL/algorithm/straightSkeleton.h>
 #include <SFCGAL/algorithm/tesselate.h>
 #include <SFCGAL/algorithm/union.h>
+#include <SFCGAL/algorithm/visibility.h>
 #include <SFCGAL/algorithm/volume.h>
 #include <SFCGAL/triangulate/triangulate2DZ.h>
 
@@ -179,28 +184,31 @@ sfcgal_geometry_is_valid_detail(const sfcgal_geometry_t *geom,
                                 sfcgal_geometry_t **invalidity_location) -> int
 {
   // invalidity location is not supported for now
-  if (invalidity_location)
+  if (invalidity_location != nullptr) {
     *invalidity_location = nullptr;
+  }
   // set to null for now
-  if (invalidity_reason)
+  if (invalidity_reason != nullptr) {
     *invalidity_reason = nullptr;
+  }
 
   const auto *g = reinterpret_cast<const SFCGAL::Geometry *>(geom);
-  if (g->hasValidityFlag())
-    return true;
+  if (g->hasValidityFlag()) {
+    return 1;
+  }
   bool is_valid = false;
   try {
-    SFCGAL::Validity validity = SFCGAL::algorithm::isValid(*g);
-    is_valid                  = validity;
-    if (!is_valid && invalidity_reason) {
+    SFCGAL::Validity const validity = SFCGAL::algorithm::isValid(*g);
+    is_valid                        = validity;
+    if (!is_valid && (invalidity_reason != nullptr)) {
       *invalidity_reason = strdup(validity.reason().c_str());
     }
   } catch (SFCGAL::Exception &e) {
-    if (invalidity_reason) {
+    if (invalidity_reason != nullptr) {
       *invalidity_reason = strdup(e.what());
     }
   }
-  return is_valid;
+  return static_cast<int>(is_valid);
 }
 
 extern "C" auto
@@ -261,6 +269,17 @@ sfcgal_geometry_as_text_decim(const sfcgal_geometry_t *pgeom, int numDecimals,
       strncpy(*buffer, wkt.c_str(), *len);)
 }
 
+extern "C" void
+sfcgal_geometry_as_wkb(const sfcgal_geometry_t *pgeom, char **buffer,
+                       size_t *len)
+{
+  SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR_NO_RET(
+      std::string wkb =
+          reinterpret_cast<const SFCGAL::Geometry *>(pgeom)->asWkb();
+      *buffer = (char *)sfcgal_alloc_handler(wkb.size() + 1); *len = wkb.size();
+      strncpy(*buffer, wkb.c_str(), *len);)
+}
+
 /**
  * Point
  */
@@ -277,6 +296,16 @@ sfcgal_point_create_from_xy(double x, double y) -> sfcgal_geometry_t *
   SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR(
       return static_cast<SFCGAL::Geometry *>(new SFCGAL::Point(x, y));)
 }
+
+extern "C" auto
+sfcgal_point_create_from_xym(double x, double y, double m)
+    -> sfcgal_geometry_t *
+{
+  SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR(
+      auto g = std::make_unique<SFCGAL::Point>(x, y); g->setM(m);
+      return static_cast<SFCGAL::Geometry *>(g.release());)
+}
+
 extern "C" auto
 sfcgal_point_create_from_xyz(double x, double y, double z)
     -> sfcgal_geometry_t *
@@ -285,6 +314,14 @@ sfcgal_point_create_from_xyz(double x, double y, double z)
       return static_cast<SFCGAL::Geometry *>(new SFCGAL::Point(x, y, z));)
 }
 
+extern "C" auto
+sfcgal_point_create_from_xyzm(double x, double y, double z, double m)
+    -> sfcgal_geometry_t *
+{
+  SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR(
+      return static_cast<SFCGAL::Geometry *>(new SFCGAL::Point(x, y, z, m));)
+}
+
 extern "C" auto
 sfcgal_point_x(const sfcgal_geometry_t *geom) -> double
 {
@@ -715,6 +752,13 @@ sfcgal_io_read_wkt(const char *str, size_t len) -> sfcgal_geometry_t *
       return SFCGAL::io::readWkt(str, len).release();)
 }
 
+extern "C" auto
+sfcgal_io_read_wkb(const char *str, size_t len) -> sfcgal_geometry_t *
+{
+  SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR(
+      return SFCGAL::io::readWkb(str, len).release();)
+}
+
 extern "C" void
 sfcgal_io_write_binary_prepared(const sfcgal_prepared_geometry_t *geom,
                                 char **buffer, size_t *len)
@@ -730,7 +774,7 @@ extern "C" auto
 sfcgal_io_read_binary_prepared(const char *str, size_t len)
     -> sfcgal_prepared_geometry_t *
 {
-  std::string                               sstr(str, len);
+  std::string const                         sstr(str, len);
   std::unique_ptr<SFCGAL::PreparedGeometry> g;
 
   try {
@@ -1151,6 +1195,49 @@ sfcgal_geometry_has_validity_flag(const sfcgal_geometry_t *geom) -> int
   return g1->hasValidityFlag() ? 1 : 0;
 }
 
+extern "C" auto
+sfcgal_geometry_extrude_straight_skeleton(const sfcgal_geometry_t *geom,
+                                          double height) -> sfcgal_geometry_t *
+{
+  const auto *g1 = reinterpret_cast<const SFCGAL::Geometry *>(geom);
+  std::unique_ptr<SFCGAL::PolyhedralSurface> polys;
+
+  try {
+    polys = SFCGAL::algorithm::extrudeStraightSkeleton(*g1, height);
+  } catch (std::exception &e) {
+    SFCGAL_WARNING("During straight_extrude_skeleton_distance(A):");
+    SFCGAL_WARNING("  with A: %s",
+                   ((const SFCGAL::Geometry *)(geom))->asText().c_str());
+    SFCGAL_ERROR("%s", e.what());
+    return nullptr;
+  }
+
+  return polys.release();
+}
+
+extern "C" auto
+sfcgal_geometry_extrude_polygon_straight_skeleton(const sfcgal_geometry_t *geom,
+                                                  double building_height,
+                                                  double roof_height)
+    -> sfcgal_geometry_t *
+{
+  const auto *g1 = reinterpret_cast<const SFCGAL::Geometry *>(geom);
+  std::unique_ptr<SFCGAL::Geometry> polys;
+
+  try {
+    polys = SFCGAL::algorithm::extrudeStraightSkeleton(*g1, building_height,
+                                                       roof_height);
+  } catch (std::exception &e) {
+    SFCGAL_WARNING("During straight_extrude_skeleton_distance(A):");
+    SFCGAL_WARNING("  with A: %s",
+                   ((const SFCGAL::Geometry *)(geom))->asText().c_str());
+    SFCGAL_ERROR("%s", e.what());
+    return nullptr;
+  }
+
+  return polys.release();
+}
+
 extern "C" auto
 sfcgal_geometry_straight_skeleton_distance_in_m(const sfcgal_geometry_t *geom)
     -> sfcgal_geometry_t *
@@ -1197,11 +1284,12 @@ sfcgal_geometry_line_sub_string(const sfcgal_geometry_t *geom, double start,
   return ls.release();
 }
 
-extern "C" sfcgal_geometry_t *
+#if !_MSC_VER
+extern "C" auto
 sfcgal_geometry_alpha_shapes(const sfcgal_geometry_t *geom, double alpha,
-                             bool allow_holes)
+                             bool allow_holes) -> sfcgal_geometry_t *
 {
-  const SFCGAL::Geometry *g1 = reinterpret_cast<const SFCGAL::Geometry *>(geom);
+  const auto *g1 = reinterpret_cast<const SFCGAL::Geometry *>(geom);
   std::unique_ptr<SFCGAL::Geometry> result;
 
   try {
@@ -1212,29 +1300,187 @@ sfcgal_geometry_alpha_shapes(const sfcgal_geometry_t *geom, double alpha,
     SFCGAL_WARNING("  with A: %s",
                    ((const SFCGAL::Geometry *)(geom))->asText().c_str());
     SFCGAL_ERROR("%s", e.what());
-    return 0;
+    return nullptr;
   }
 
   return result.release();
 }
 
-extern "C" sfcgal_geometry_t *
+extern "C" auto
 sfcgal_geometry_optimal_alpha_shapes(const sfcgal_geometry_t *geom,
                                      bool allow_holes, size_t nb_components)
+    -> sfcgal_geometry_t *
 {
-  const SFCGAL::Geometry *g1 = reinterpret_cast<const SFCGAL::Geometry *>(geom);
+  const auto *g1 = reinterpret_cast<const SFCGAL::Geometry *>(geom);
   std::unique_ptr<SFCGAL::Geometry> result;
 
   try {
     result = SFCGAL::algorithm::optimal_alpha_shapes(
         g1->as<const SFCGAL::Geometry>(), allow_holes, nb_components);
   } catch (std::exception &e) {
-    SFCGAL_WARNING("During optimal_alpha_shapes(A, %g %g):", allow_holes,
-                   nb_components);
+    SFCGAL_WARNING("During optimal_alpha_shapes(A, %g %g):",
+                   static_cast<int>(allow_holes), nb_components);
     SFCGAL_WARNING("  with A: %s",
                    ((const SFCGAL::Geometry *)(geom))->asText().c_str());
     SFCGAL_ERROR("%s", e.what());
-    return 0;
+    return nullptr;
+  }
+
+  return result.release();
+}
+#endif
+
+extern "C" auto
+sfcgal_y_monotone_partition_2(const sfcgal_geometry_t *geom)
+    -> sfcgal_geometry_t *
+{
+  const auto *g1 = reinterpret_cast<const SFCGAL::Geometry *>(geom);
+  std::unique_ptr<SFCGAL::Geometry> result;
+
+  try {
+    result = SFCGAL::algorithm::partition_2(g1->as<const SFCGAL::Geometry>(),
+                                            SFCGAL::algorithm::y_monotone);
+  } catch (std::exception &e) {
+    SFCGAL_WARNING("During y_monotone_partition_2(A):");
+    SFCGAL_WARNING("  with A: %s",
+                   ((const SFCGAL::Geometry *)(geom))->asText().c_str());
+    SFCGAL_ERROR("%s", e.what());
+    return nullptr;
+  }
+
+  return result.release();
+}
+
+extern "C" auto
+sfcgal_approx_convex_partition_2(const sfcgal_geometry_t *geom)
+    -> sfcgal_geometry_t *
+{
+  const auto *g1 = reinterpret_cast<const SFCGAL::Geometry *>(geom);
+  std::unique_ptr<SFCGAL::Geometry> result;
+
+  try {
+    result = SFCGAL::algorithm::partition_2(g1->as<const SFCGAL::Geometry>(),
+                                            SFCGAL::algorithm::approx_convex);
+  } catch (std::exception &e) {
+    SFCGAL_WARNING("During approx_convex_partition_2(A):");
+    SFCGAL_WARNING("  with A: %s",
+                   ((const SFCGAL::Geometry *)(geom))->asText().c_str());
+    SFCGAL_ERROR("%s", e.what());
+    return nullptr;
+  }
+
+  return result.release();
+}
+
+extern "C" auto
+sfcgal_greene_approx_convex_partition_2(const sfcgal_geometry_t *geom)
+    -> sfcgal_geometry_t *
+{
+  const auto *g1 = reinterpret_cast<const SFCGAL::Geometry *>(geom);
+  std::unique_ptr<SFCGAL::Geometry> result;
+
+  try {
+    result =
+        SFCGAL::algorithm::partition_2(g1->as<const SFCGAL::Geometry>(),
+                                       SFCGAL::algorithm::greene_approx_convex);
+  } catch (std::exception &e) {
+    SFCGAL_WARNING("During greene_approx_convex_partition_2(A):");
+    SFCGAL_WARNING("  with A: %s",
+                   ((const SFCGAL::Geometry *)(geom))->asText().c_str());
+    SFCGAL_ERROR("%s", e.what());
+    return nullptr;
+  }
+
+  return result.release();
+}
+extern "C" auto
+sfcgal_optimal_convex_partition_2(const sfcgal_geometry_t *geom)
+    -> sfcgal_geometry_t *
+{
+  const auto *g1 = reinterpret_cast<const SFCGAL::Geometry *>(geom);
+  std::unique_ptr<SFCGAL::Geometry> result;
+
+  try {
+    result = SFCGAL::algorithm::partition_2(g1->as<const SFCGAL::Geometry>(),
+                                            SFCGAL::algorithm::optimal_convex);
+  } catch (std::exception &e) {
+    SFCGAL_WARNING("During optimal_convex_partition_2(A):");
+    SFCGAL_WARNING("  with A: %s",
+                   ((const SFCGAL::Geometry *)(geom))->asText().c_str());
+    SFCGAL_ERROR("%s", e.what());
+    return nullptr;
+  }
+
+  return result.release();
+}
+
+extern "C" auto
+sfcgal_geometry_visibility_point(const sfcgal_geometry_t *polygon,
+                                 const sfcgal_geometry_t *point)
+    -> sfcgal_geometry_t *
+{
+
+  const auto *poly = reinterpret_cast<const SFCGAL::Geometry *>(polygon);
+  const auto *pt   = reinterpret_cast<const SFCGAL::Geometry *>(point);
+  std::unique_ptr<SFCGAL::Geometry> result;
+
+  if (poly->geometryTypeId() != SFCGAL::TYPE_POLYGON) {
+    SFCGAL_ERROR("visibility() only applies to polygons");
+    return result.release();
+  }
+
+  if (pt->geometryTypeId() != SFCGAL::TYPE_POINT) {
+    SFCGAL_ERROR("second argument must be a point");
+    return result.release();
+  }
+
+  try {
+    result = SFCGAL::algorithm::visibility(poly->as<const SFCGAL::Polygon>(),
+                                           pt->as<const SFCGAL::Point>());
+  } catch (std::exception &e) {
+    SFCGAL_WARNING("During visibility(A, B) :");
+    SFCGAL_WARNING("  with A: %s", poly->asText().c_str());
+    SFCGAL_WARNING("  and B: %s", pt->asText().c_str());
+    SFCGAL_ERROR("%s", e.what());
+    return result.release();
+  }
+
+  return result.release();
+}
+
+extern "C" auto
+sfcgal_geometry_visibility_segment(const sfcgal_geometry_t *polygon,
+                                   const sfcgal_geometry_t *pointA,
+                                   const sfcgal_geometry_t *pointB)
+    -> sfcgal_geometry_t *
+{
+  const auto *poly = reinterpret_cast<const SFCGAL::Geometry *>(polygon);
+  const auto *ptA  = reinterpret_cast<const SFCGAL::Geometry *>(pointA);
+  const auto *ptB  = reinterpret_cast<const SFCGAL::Geometry *>(pointB);
+  std::unique_ptr<SFCGAL::Geometry> result;
+
+  if (poly->geometryTypeId() != SFCGAL::TYPE_POLYGON) {
+    SFCGAL_ERROR("visibility() only applies to polygons");
+    return result.release();
+  }
+
+  if ((ptA->geometryTypeId() != SFCGAL::TYPE_POINT) ||
+      (ptB->geometryTypeId() != SFCGAL::TYPE_POINT)) {
+    SFCGAL_ERROR("second and third argument must be a point");
+    return result.release();
+  }
+
+  try {
+    result = SFCGAL::algorithm::visibility(poly->as<const SFCGAL::Polygon>(),
+                                           ptA->as<const SFCGAL::Point>(),
+                                           ptB->as<const SFCGAL::Point>());
+  } catch (std::exception &e) {
+    SFCGAL_WARNING("During visibility(A, B, C) :");
+    SFCGAL_WARNING("  with A: %s", poly->asText().c_str());
+    SFCGAL_WARNING("  and B: %s", ptA->asText().c_str());
+    SFCGAL_WARNING("  and C: %s", ptB->asText().c_str());
+    SFCGAL_ERROR("%s", e.what());
+    return result.release();
   }
 
   return result.release();
