@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #ifndef _SFCGAL_CAPI_H_
 #define _SFCGAL_CAPI_H_
@@ -57,9 +57,9 @@ typedef enum {
   //     TYPE_SURFACE             = 14, //abstract
   SFCGAL_TYPE_POLYHEDRALSURFACE   = 15,
   SFCGAL_TYPE_TRIANGULATEDSURFACE = 16,
+  SFCGAL_TYPE_TRIANGLE            = 17,
 
   //-- not official codes
-  SFCGAL_TYPE_TRIANGLE   = 100, // 17 in Wikipedia???
   SFCGAL_TYPE_SOLID      = 101,
   SFCGAL_TYPE_MULTISOLID = 102
 } sfcgal_geometry_type_t;
@@ -162,6 +162,14 @@ SFCGAL_API void
 sfcgal_geometry_as_text_decim(const sfcgal_geometry_t *, int numDecimals,
                               char **buffer, size_t *len);
 
+/**
+ * Returns a WKB representation of the given geometry
+ * @post buffer is returned allocated and must be freed by the caller
+ * @ingroup capi
+ */
+SFCGAL_API void
+sfcgal_geometry_as_wkb(const sfcgal_geometry_t *, char **buffer, size_t *len);
+
 /**
  * Creates an empty point
  * @ingroup capi
@@ -183,6 +191,20 @@ sfcgal_point_create_from_xy(double x, double y);
 SFCGAL_API sfcgal_geometry_t *
 sfcgal_point_create_from_xyz(double x, double y, double z);
 
+/**
+ * Creates a point from three X, Y and M coordinates
+ * @ingroup capi
+ */
+SFCGAL_API sfcgal_geometry_t *
+sfcgal_point_create_from_xym(double x, double y, double m);
+
+/**
+ * Creates a point from four X, Y, Z and M coordinates
+ * @ingroup capi
+ */
+SFCGAL_API sfcgal_geometry_t *
+sfcgal_point_create_from_xyzm(double x, double y, double z, double m);
+
 /**
  * Returns the X coordinate of the given Point
  * @pre the given geometry must be a Point
@@ -679,6 +701,12 @@ sfcgal_io_read_wkt(const char *, size_t len);
 SFCGAL_API sfcgal_prepared_geometry_t *
 sfcgal_io_read_ewkt(const char *, size_t len);
 
+/**
+ * io::readWKB
+ */
+SFCGAL_API sfcgal_geometry_t *
+sfcgal_io_read_wkb(const char *, size_t len);
+
 /**
  * Serialization
  */
@@ -966,6 +994,31 @@ sfcgal_geometry_straight_skeleton(const sfcgal_geometry_t *geom);
 SFCGAL_API sfcgal_geometry_t *
 sfcgal_geometry_straight_skeleton_distance_in_m(const sfcgal_geometry_t *geom);
 
+/**
+ * Returns the extrude straight skeleton of the given Polygon
+ * @pre geom must be a Polygon
+ * @pre isValid(geom) == true
+ * @pre height != 0
+ * @ingroup capi
+ */
+SFCGAL_API sfcgal_geometry_t *
+sfcgal_geometry_extrude_straight_skeleton(const sfcgal_geometry_t *geom,
+                                          double                   height);
+
+/**
+ * Returns the union of the polygon z-extrusion (with respect to
+ * building_height) and the extrude straight skeleton (with respect to
+ * roof_height) of the given Polygon
+ * @pre geom must be a Polygon
+ * @pre isValid(geom) == true
+ * @pre roof_height != 0
+ * @ingroup capi
+ */
+SFCGAL_API sfcgal_geometry_t *
+sfcgal_geometry_extrude_polygon_straight_skeleton(const sfcgal_geometry_t *geom,
+                                                  double building_height,
+                                                  double roof_height);
+
 /**
  * Returns the approximate medial axis for the given Polygon
  * Approximate medial axis is based on straight skeleton
@@ -1008,6 +1061,7 @@ SFCGAL_API sfcgal_geometry_t *
 sfcgal_geometry_line_sub_string(const sfcgal_geometry_t *geom, double start,
                                 double end);
 
+#if !_MSC_VER
 /**
  * Returns the alpha shapes of geom
  * @pre isValid(geom) == true
@@ -1030,6 +1084,73 @@ sfcgal_geometry_alpha_shapes(const sfcgal_geometry_t *geom, double alpha,
 SFCGAL_API sfcgal_geometry_t *
 sfcgal_geometry_optimal_alpha_shapes(const sfcgal_geometry_t *geom,
                                      bool allow_holes, size_t nb_components);
+#endif
+
+/**
+ * Returns the y monotone partition of a geometry (polygon without hole)
+ * @pre isValid(geom) == true
+ * @post isValid(return) == true
+ * @ingroup capi
+ */
+SFCGAL_API sfcgal_geometry_t *
+sfcgal_y_monotone_partition_2(const sfcgal_geometry_t *geom);
+
+/**
+ * Returns the approximal convex partition of a geometry (polygon without hole)
+ * @pre isValid(geom) == true
+ * @post isValid(return) == true
+ * @ingroup capi
+ */
+SFCGAL_API sfcgal_geometry_t *
+sfcgal_approx_convex_partition_2(const sfcgal_geometry_t *geom);
+
+/**
+ * Returns the greene approximal convex partition of a geometry (polygon without
+ * hole)
+ * @pre isValid(geom) == true
+ * @post isValid(return) == true
+ * @ingroup capi
+ */
+SFCGAL_API sfcgal_geometry_t *
+sfcgal_greene_approx_convex_partition_2(const sfcgal_geometry_t *geom);
+
+/**
+ * Returns the optimal convex partition of a geometry (polygon without hole)
+ * @pre isValid(geom) == true
+ * @post isValid(return) == true
+ * @ingroup capi
+ */
+SFCGAL_API sfcgal_geometry_t *
+sfcgal_optimal_convex_partition_2(const sfcgal_geometry_t *geom);
+
+/**
+ * Returns the visibility polygon of a Point inside a Polygon
+ * @param polygon input geometry
+ * @param point input geometry
+ * @ingroup capi
+ * @pre polygon is a valid geometry
+ * @pre point must be inside polygon or on the boundary
+ */
+SFCGAL_API sfcgal_geometry_t *
+sfcgal_geometry_visibility_point(const sfcgal_geometry_t *polygon,
+                                 const sfcgal_geometry_t *point);
+
+/**
+ * @brief build the visibility polygon of the segment [pointA ; pointB] on a
+ * Polygon
+ * @param polygon input geometry
+ * @param pointA input geometry
+ * @param pointB input geometry
+ * @ingroup public_api
+ * @pre polygon is a valid geometry
+ * @pre pointA and pointB must be vertices of poly, adjacents and respect the
+ * direction
+ */
+SFCGAL_API sfcgal_geometry_t *
+sfcgal_geometry_visibility_segment(const sfcgal_geometry_t *polygon,
+                                   const sfcgal_geometry_t *pointA,
+                                   const sfcgal_geometry_t *pointB);
+
 /*--------------------------------------------------------------------------------------*
  *
  * Error handling
