@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/detail/ForceValidityVisitor.h>
 
@@ -17,8 +17,7 @@
 #include <SFCGAL/Triangle.h>
 #include <SFCGAL/TriangulatedSurface.h>
 
-namespace SFCGAL {
-namespace detail {
+namespace SFCGAL::detail {
 
 ///
 ///
@@ -161,5 +160,4 @@ ForceValidityVisitor::visit(TriangulatedSurface &g)
   }
 }
 
-} // namespace detail
-} // namespace SFCGAL
+} // namespace SFCGAL::detail
