@@ -1,14 +1,13 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/detail/Interval.h>
 #include <SFCGAL/numeric.h>
 
 #include <algorithm>
 
-namespace SFCGAL {
-namespace detail {
+namespace SFCGAL::detail {
 
 ///
 ///
@@ -44,7 +43,6 @@ Interval::operator=(const Interval &other) -> Interval & = default;
 ///
 ///
 ///
-Interval::~Interval() = default;
 
 ///
 ///
@@ -118,7 +116,7 @@ Interval::intersects(const Interval &other) const -> bool
     return false;
   }
 
-  return !(_lower > other._upper || _upper < other._lower);
+  return _lower <= other._upper && _upper >= other._lower;
 }
 
 ///
@@ -143,5 +141,4 @@ Interval::operator!=(const Interval &other) const -> bool
   return !((*this) == other);
 }
 
-} // namespace detail
-} // namespace SFCGAL
+} // namespace SFCGAL::detail
