@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #ifndef _SFCGAL_DETAIL_INTERVAL_H_
 #define _SFCGAL_DETAIL_INTERVAL_H_
@@ -36,10 +36,6 @@ public:
    */
   Interval &
   operator=(const Interval &other);
-  /**
-   * destructor
-   */
-  ~Interval();
 
   /**
    * indicates if the interval is empty
