@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/Geometry.h>
 #include <SFCGAL/Point.h>
@@ -9,9 +9,7 @@
 #include <SFCGAL/detail/GetPointsVisitor.h>
 #include <SFCGAL/detail/algorithm/coversPoints.h>
 
-namespace SFCGAL {
-namespace detail {
-namespace algorithm {
+namespace SFCGAL::detail::algorithm {
 template <int Dim>
 auto
 _coversPoints(const Geometry &ga, const Geometry &gb) -> bool
@@ -20,18 +18,15 @@ _coversPoints(const Geometry &ga, const Geometry &gb) -> bool
     return false;
   }
 
-  GeometrySet<Dim> gsa(ga);
+  GeometrySet<Dim> const gsa(ga);
 
   // get all points of gb;
   detail::GetPointsVisitor visitor;
   gb.accept(visitor);
 
-  for (detail::GetPointsVisitor::const_iterator it = visitor.points.begin();
-       it != visitor.points.end(); ++it) {
-    const Point *ppt = *it;
-
+  for (const auto *ppt : visitor.points) {
     // a geometry set of one point
-    GeometrySet<Dim> gsp(*ppt);
+    GeometrySet<Dim> const gsp(*ppt);
 
     if (!SFCGAL::algorithm::intersects(gsp, gsa)) {
       return false;
@@ -52,6 +47,4 @@ coversPoints3D(const Geometry &ga, const Geometry &gb) -> bool
 {
   return _coversPoints<3>(ga, gb);
 }
-} // namespace algorithm
-} // namespace detail
-} // namespace SFCGAL
+} // namespace SFCGAL::detail::algorithm
