@@ -1,16 +1,14 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/detail/graph/Edge.h>
 
-namespace SFCGAL {
-namespace graph {
+namespace SFCGAL::graph {
 
 ///
 ///
 ///
 Edge::Edge(const int &face_) : face(face_) {}
 
-} // namespace graph
-} // namespace SFCGAL
+} // namespace SFCGAL::graph
