@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/detail/io/WktWriter.h>
 
@@ -20,9 +20,7 @@
 #include <boost/exception/all.hpp>
 #include <exception>
 
-namespace SFCGAL {
-namespace detail {
-namespace io {
+namespace SFCGAL::detail::io {
 
 namespace impl {
 auto
@@ -121,13 +119,24 @@ WktWriter::write(const Geometry &g, bool exact)
 void
 WktWriter::writeCoordinateType(const Geometry &g)
 {
-  if (g.is3D() && g.isMeasured()) {
-    _s << " ZM";
+  if (g.is3D() && !g.isMeasured()) {
+    _s << " Z";
   } else if (!g.is3D() && g.isMeasured()) {
     _s << " M";
+  } else if (g.is3D() && g.isMeasured()) {
+    _s << " ZM";
   }
 }
 
+static auto
+fixZeroNeg(double val, int precision) -> double
+{
+  if (std::abs(val) < std::pow(10, -precision)) {
+    return 0;
+  }
+  return val;
+}
+
 ///
 ///
 ///
@@ -143,16 +152,17 @@ WktWriter::writeCoordinate(const Point &g)
       impl::writeFT(_s, CGAL::exact(g.z()));
     }
   } else {
-    _s << g.x() << " " << g.y();
+    _s << fixZeroNeg(CGAL::to_double(g.x()), _s.precision()) << " "
+       << fixZeroNeg(CGAL::to_double(g.y()), _s.precision());
 
     if (g.is3D()) {
-      _s << " " << g.z();
+      _s << " " << fixZeroNeg(CGAL::to_double(g.z()), _s.precision());
     }
   }
 
   // m coordinate
   if (g.isMeasured()) {
-    _s << " " << g.m();
+    _s << " " << fixZeroNeg(CGAL::to_double(g.m()), _s.precision());
   }
 }
 
@@ -530,6 +540,4 @@ WktWriter::writeInner(const Solid &g)
   _s << ")"; // end SOLID
 }
 
-} // namespace io
-} // namespace detail
-} // namespace SFCGAL
+} // namespace SFCGAL::detail::io
