@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/detail/polygonSetToMultiPolygon.h>
 
@@ -8,8 +8,7 @@
 
 #include <list>
 
-namespace SFCGAL {
-namespace detail {
+namespace SFCGAL::detail {
 
 ///
 ///
@@ -25,13 +24,11 @@ polygonSetToMultiPolygon(const CGAL::Polygon_set_2<Kernel> &polygonSet)
 
   std::unique_ptr<MultiPolygon> result(new MultiPolygon);
 
-  for (std::list<Polygon_with_holes_2>::const_iterator it = res.begin();
-       it != res.end(); ++it) {
-    result->addGeometry(new Polygon(*it));
+  for (auto &re : res) {
+    result->addGeometry(new Polygon(re));
   }
 
   return result;
 }
 
-} // namespace detail
-} // namespace SFCGAL
+} // namespace SFCGAL::detail
