@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #ifndef _SFCGAL_TOOLS_INPUTSTREAMREADER_H_
 #define _SFCGAL_TOOLS_INPUTSTREAMREADER_H_
@@ -152,6 +152,15 @@ public:
     }
   }
 
+  auto
+  readBytes(std::string &buffer, size_t bytesToRead) -> void
+  {
+    begin();
+
+    _s.read(&buffer[0], bytesToRead);
+
+    commit();
+  }
   /// \brief save input stream state (read position)
   void
   begin()
