@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/detail/transform/AffineTransform2.h>
 
@@ -8,8 +8,7 @@
 
 #include <utility>
 
-namespace SFCGAL {
-namespace transform {
+namespace SFCGAL::transform {
 
 ///
 ///
@@ -28,11 +27,11 @@ AffineTransform2::transform(Point &p)
   if (!p.isEmpty()) {
     // FIXME add a Point::Point( Kernel::Point_2&, double m );
     Point pt(p.toPoint_2().transform(_transform));
-    if (p.isMeasured())
+    if (p.isMeasured()) {
       pt.setM(p.m());
+    }
     p = pt;
   }
 }
 
-} // namespace transform
-} // namespace SFCGAL
+} // namespace SFCGAL::transform
