@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/Point.h>
 #include <SFCGAL/Polygon.h>
@@ -8,8 +8,7 @@
 #include <SFCGAL/algorithm/orientation.h>
 #include <SFCGAL/detail/transform/ForceOrderPoints.h>
 
-namespace SFCGAL {
-namespace transform {
+namespace SFCGAL::transform {
 
 ///
 ///
@@ -20,7 +19,7 @@ ForceOrderPoints::ForceOrderPoints(bool orientCCW) : _orientCCW(orientCCW) {}
 ///
 ///
 void
-ForceOrderPoints::transform(Point &)
+ForceOrderPoints::transform(Point & /*p*/)
 {
 }
 
@@ -82,5 +81,4 @@ ForceOrderPoints::visit(Polygon &p)
   }
 }
 
-} // namespace transform
-} // namespace SFCGAL
+} // namespace SFCGAL::transform
