@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/Point.h>
 #include <SFCGAL/Polygon.h>
@@ -10,14 +10,12 @@
 
 #include <utility>
 
-namespace SFCGAL {
-namespace transform {
+namespace SFCGAL::transform {
 
 ///
 ///
 ///
-ForceZOrderPoints::ForceZOrderPoints(Kernel::FT defaultZ)
-    : _defaultZ(std::move(defaultZ))
+ForceZOrderPoints::ForceZOrderPoints(Kernel::FT defaultZ) : _defaultZ(defaultZ)
 {
 }
 
@@ -72,5 +70,4 @@ ForceZOrderPoints::visit(Polygon &p)
   }
 }
 
-} // namespace transform
-} // namespace SFCGAL
+} // namespace SFCGAL::transform
