@@ -1,13 +1,12 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/detail/transform/RoundTransform.h>
 
 #include <SFCGAL/Point.h>
 
-namespace SFCGAL {
-namespace transform {
+namespace SFCGAL::transform {
 
 ///
 ///
@@ -23,5 +22,4 @@ RoundTransform::transform(Point &p)
   p.coordinate().round(_scale);
 }
 
-} // namespace transform
-} // namespace SFCGAL
+} // namespace SFCGAL::transform
