@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/detail/triangulate/ConstraintDelaunayTriangulation.h>
 
@@ -9,13 +9,12 @@
 
 #include <SFCGAL/detail/triangulate/markDomains.h>
 
-namespace SFCGAL {
-namespace triangulate {
+namespace SFCGAL::triangulate {
 
 ///
 ///
 ///
-ConstraintDelaunayTriangulation::ConstraintDelaunayTriangulation() : _cdt() {}
+ConstraintDelaunayTriangulation::ConstraintDelaunayTriangulation() = default;
 
 ///
 ///
@@ -97,10 +96,9 @@ ConstraintDelaunayTriangulation::projectionPlane() const -> Kernel::Plane_3
 {
   if (_projectionPlane) {
     return *_projectionPlane;
-  } else {
-    return Kernel::Plane_3(Kernel::RT(0), Kernel::RT(0), Kernel::RT(1),
-                           Kernel::RT(0));
   }
+  return Kernel::Plane_3(Kernel::RT(0), Kernel::RT(0), Kernel::RT(1),
+                         Kernel::RT(0));
 }
 
 ///
@@ -153,5 +151,4 @@ ConstraintDelaunayTriangulation::getTriangulatedSurface() const
   return result;
 }
 
-} // namespace triangulate
-} // namespace SFCGAL
+} // namespace SFCGAL::triangulate
