@@ -1,6 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <SFCGAL/numeric.h>
 
@@ -35,12 +35,11 @@ round(const CGAL::Gmpq &v) -> CGAL::Gmpz
   if (v < 0) {
     // ceil( v - 0.5 ) ;
     return ceil(v - CGAL::Gmpq(1, 2));
-  } else if (v == 0) {
-    return 0;
-  } else {
-    // floor( v + 0.5 ) ;
-    return floor(v + CGAL::Gmpq(1, 2));
   }
+  if (v == 0) {
+    return 0;
+  } // floor( v + 0.5 ) ;
+  return floor(v + CGAL::Gmpq(1, 2));
 }
 
 #ifdef CGAL_USE_GMPXX
@@ -73,15 +72,14 @@ round(const mpq_class &v) -> mpz_class
 {
   if (v < 0) {
     // ceil( v - 0.5 ) ;
-    mpq_class tmp = v - mpq_class(1, 2);
+    mpq_class const tmp = v - mpq_class(1, 2);
     return ceil(tmp);
-  } else if (v == 0) {
-    return 0;
-  } else {
-    // floor( v + 0.5 ) ;
-    mpq_class tmp = v + mpq_class(1, 2);
-    return floor(tmp);
   }
+  if (v == 0) {
+    return 0;
+  } // floor( v + 0.5 ) ;
+  mpq_class const tmp = v + mpq_class(1, 2);
+  return floor(tmp);
 }
 #endif
 
